ProSHADE: src/bin/bin.cpp Source File

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

bin.cpp
Go to the documentation of this file.
1
26 //==================================================== DOxygen main page specifications
27
1304 //==================================================== ProSHADE
1305 #include "../proshade/ProSHADE.hpp"
1306
1307 //==================================================== Main
1308 int main ( int argc, char **argv )
1309 {
1310 //================================================ Create the settings object and parse the command line arguments
1311 ProSHADE_settings* settings = new ProSHADE_settings ( );
1312 settings->getCommandLineParams ( argc, argv );
1313
1314 //================================================ Execute
1315 ProSHADE_run *run = new ProSHADE_run ( settings );
1316
1317 //================================================ Release the settings object
1318 delete settings;
1319
1320 //================================================ Release the executive object
1321 delete run;
1322
1323 //================================================ DONE
1324 return ( 0 );
1325 }
ProSHADE_run
This class provides the access point to the library.
Definition: ProSHADE.hpp:39
ProSHADE_settings
This class stores all the settings and is passed to the executive classes instead of a multitude of p...
Definition: ProSHADE_settings.hpp:86
ProSHADE_settings::getCommandLineParams
void getCommandLineParams(int argc, char **argv)
This function parses the command line arguments into the settings object.
Definition: ProSHADE.cpp:1572